==> haskell-polyparse-1.12-4-i686.pkg.tar.xz: usr/share/haskell/register/haskell-polyparse.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: polyparse
version: 1.12
id: polyparse-1.12-2dxp3MdYSYOEcDgRo6TZWF
key: polyparse-1.12-2dxp3MdYSYOEcDgRo6TZWF
license: LGPL
copyright: (c) 2006-2016 Malcolm Wallace
maintainer: author
homepage: http://code.haskell.org/~malcolm/polyparse/
synopsis: A variety of alternative parser combinator libraries.
description:
    A variety of alternative parser combinator libraries, including
    the original HuttonMeijer set.  The Poly sets have features like
    good error reporting, arbitrary token type, running state, lazy
    parsing, and so on.  Finally, Text.Parse is a proposed
    replacement for the standard Read class, for better
    deserialisation of Haskell values from Strings.
category: Text, Parsing
author: Malcolm Wallace <Malcolm.Wallace@me.com>
exposed: True
exposed-modules:
    Text.ParserCombinators.HuttonMeijer
    Text.ParserCombinators.HuttonMeijerWallace
    Text.ParserCombinators.Poly Text.ParserCombinators.Poly.Base
    Text.ParserCombinators.Poly.Result
    Text.ParserCombinators.Poly.Parser
    Text.ParserCombinators.Poly.Plain Text.ParserCombinators.Poly.Lazy
    Text.ParserCombinators.Poly.StateParser
    Text.ParserCombinators.Poly.State
    Text.ParserCombinators.Poly.StateLazy
    Text.ParserCombinators.Poly.Lex Text.Parse
    Text.ParserCombinators.Poly.ByteString
    Text.ParserCombinators.Poly.ByteStringChar Text.Parse.ByteString
    Text.ParserCombinators.Poly.Text
    Text.ParserCombinators.Poly.StateText
abi: 7e301ead215f0fda7fd84891f9fc054b
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/polyparse-1.12
library-dirs: /usr/lib/ghc-8.0.2/site-local/polyparse-1.12
dynamic-library-dirs: /usr/lib/i386-linux-ghc-8.0.2
data-dir: /usr/share/i386-linux-ghc-8.0.2/polyparse-1.12
hs-libraries: HSpolyparse-1.12-2dxp3MdYSYOEcDgRo6TZWF
depends:
    base-4.9.1.0 bytestring-0.10.8.1
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq
haddock-interfaces: /usr/share/doc/haskell-polyparse/html/polyparse.haddock
haddock-html: /usr/share/doc/haskell-polyparse/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-polyparse-1.12-6-i686.pkg.tar.xz: usr/share/haskell/register/haskell-polyparse.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: polyparse
version: 1.12
id: polyparse-1.12-4cjrjVV9T2CBEJ6qvS0lIS
key: polyparse-1.12-4cjrjVV9T2CBEJ6qvS0lIS
license: LGPL
copyright: (c) 2006-2016 Malcolm Wallace
maintainer: author
homepage: http://code.haskell.org/~malcolm/polyparse/
synopsis: A variety of alternative parser combinator libraries.
description:
    A variety of alternative parser combinator libraries, including
    the original HuttonMeijer set.  The Poly sets have features like
    good error reporting, arbitrary token type, running state, lazy
    parsing, and so on.  Finally, Text.Parse is a proposed
    replacement for the standard Read class, for better
    deserialisation of Haskell values from Strings.
category: Text, Parsing
author: Malcolm Wallace <Malcolm.Wallace@me.com>
exposed: True
indefinite: False
exposed-modules:
    Text.Parse Text.Parse.ByteString
    Text.ParserCombinators.HuttonMeijer
    Text.ParserCombinators.HuttonMeijerWallace
    Text.ParserCombinators.Poly Text.ParserCombinators.Poly.Base
    Text.ParserCombinators.Poly.ByteString
    Text.ParserCombinators.Poly.ByteStringChar
    Text.ParserCombinators.Poly.Lazy Text.ParserCombinators.Poly.Lex
    Text.ParserCombinators.Poly.Parser
    Text.ParserCombinators.Poly.Plain
    Text.ParserCombinators.Poly.Result
    Text.ParserCombinators.Poly.State
    Text.ParserCombinators.Poly.StateLazy
    Text.ParserCombinators.Poly.StateParser
    Text.ParserCombinators.Poly.StateText
    Text.ParserCombinators.Poly.Text
abi: 7ffa3fcddbc6dcf67e1c58e3119f38fe
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/polyparse-1.12
library-dirs: /usr/lib/ghc-8.2.1/site-local/polyparse-1.12
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/polyparse-1.12
hs-libraries: HSpolyparse-1.12-4cjrjVV9T2CBEJ6qvS0lIS
depends:
    base-4.10.0.0 bytestring-0.10.8.2
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
haddock-interfaces: /usr/share/doc/haskell-polyparse/html/polyparse.haddock
haddock-html: /usr/share/doc/haskell-polyparse/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
